<?php

namespace HCM\FPA\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use Doctrine\ORM\EntityManager;
use HCM\FPA\Logic\EventoUnidadeLogic;

class EventoUnidadeController extends Crud {

    protected $dataSourceNameGet = 'getEventoUnidade';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO','P_DTMESCOMPETENC', 'P_NRESTRUTURAM');
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, EntityManager $entityManager){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->entityManager = $entityManager;
        parent::__construct($dataSourceManager);
    }

    public function getEventoUnidade(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameGet);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setEventoUnidade(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'fpa_eventounidade';
            $EventoUnidadeLogic = new EventoUnidadeLogic($this->entityManager, $this->hcmParameters);
            foreach ($request->getDataSet()->getRows() as &$row) {
                $permiteSalvar = true;
                $eventoExiste = $EventoUnidadeLogic->verificaEventosUnidade($row['NRORG'], $this->hcmParameters->getDtCompetencia(), $row['NRESTRUTURAM']);
                foreach($eventoExiste as $evento) {
                    if($evento['NREVENTOM'] == $row['NREVENTOM']) {
                        $permiteSalvar = false;
                    }
                }
                
                if($permiteSalvar) {
                    if (array_key_exists('NREVENTOUNIDADE', $row)) {
                        if ($row['NREVENTOUNIDADE'] === '') {
                            $row['NREVENTOUNIDADE'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_EVENTOUNIDADE', 1, 12, true); 
                        }
                    } else {
                        $row['NREVENTOUNIDADE'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_EVENTOUNIDADE', 1, 12, true); 
                    }
                    parent::save($request, $response);
                } else {
                    $response->setError(new \Zeedhi\Framework\DTO\Response\Error("Este evento já foi inserido para esta unidade!", 500));
                }
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteEventoUnidade(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            $this->dataSourceName = 'fpa_eventounidade';
            parent::delete($request, $response);
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }
    
    public function cadAutoEventoUnidade(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $EventoUnidadeLogic = new EventoUnidadeLogic($this->entityManager, $this->hcmParameters);
            foreach ($request->getDataSet()->getRows() as &$row) {
                $EventoUnidadeLogic->cadAutoEventoUnidade($row);
                
                $response->addNotification(new DTO\Response\Notification('cadAutoEventoUnidade', DTO\Response\Notification::TYPE_SUCCESS));
            }
        } catch(\Exception $e) {
             if ($e->getCode() != 0) {
                $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            } else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
    
} 