-- ============================================================
--   DATABASE NAME:  FOLHA                                     
--   CREATED ON:     10/01/2019                                
-- ============================================================

-- ============================================================
--   TABLE: ESTRUTURAM
-- ============================================================
ALTER TABLE ESTRUTURAM ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   TABLE: FPA_EVENTOM
-- ============================================================
ALTER TABLE FPA_EVENTOM ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   TABLE: GPE_OCUPACAOM
-- ============================================================
ALTER TABLE GPE_OCUPACAOM ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   TABLE: GPE_HORDIAM
-- ============================================================
ALTER TABLE GPE_HORDIAM ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   TABLE: GPE_PROCESSADMJUD
-- ============================================================
ALTER TABLE GPE_PROCESSADMJUD ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   TABLE: GPE_PESSOA
-- ============================================================
ALTER TABLE GPE_PESSOA ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   TABLE: GPE_VINCULOM
-- ============================================================
ALTER TABLE GPE_VINCULOM ADD DTESOCIAL DATE NULL
/

-- ============================================================
--   EVENTO: S-1000
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S1000_EM
  BEFORE UPDATE
  ON ESTRUTURAM FOR EACH ROW
BEGIN
  IF :NEW.DTINIVIGENCIA <> :OLD.DTINIVIGENCIA OR
     :NEW.DTFIMVIGENCIA <> :OLD.DTFIMVIGENCIA
  THEN
    :NEW.DTESOCIAL := SYSDATE;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1000_EH
  AFTER INSERT OR UPDATE
  ON ESTRUTURAH FOR EACH ROW
BEGIN
  IF INSERTING OR
     (UPDATING AND (:NEW.NMRAZSOCESTRUT <> :OLD.NMRAZSOCESTRUT OR
                    :NEW.CDNATUJURI <> :OLD.CDNATUJURI OR
                    :NEW.CDCNAE <> :OLD.CDCNAE OR
                    :NEW.NRCLASSTRIBUT <> :OLD.NRCLASSTRIBUT OR
                    :NEW.NRPARCENTISIN <> :OLD.NRPARCENTISIN)
     )
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRESTRUTURAM = :NEW.NRESTRUTURAM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1000_CLASTRIB
  AFTER UPDATE
  ON CLASSTRIBUT FOR EACH ROW
BEGIN
  IF :NEW.CDESOCIAL <> :OLD.CDESOCIAL
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRESTRUTURAM) IN (SELECT EM.NRORG, EM.NRESTRUTURAM
                                       FROM ESTRUTURAM EM
                                       JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                                         AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                                         AND EH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                                                   WHERE H1.NRORG = EH.NRORG
                                                                                     AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                                                     AND H1.DTMESCOMPETENC <= SYSDATE)
                                      WHERE EH.NRCLASSTRIBUT = :NEW.NRCLASSTRIBUT);
  END IF;
END;

-- ============================================================
--   EVENTO: S-1005
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S1005_EM
  BEFORE UPDATE
  ON ESTRUTURAM FOR EACH ROW
BEGIN
  IF :NEW.DTINIVIGENCIA <> :OLD.DTINIVIGENCIA OR
     :NEW.DTFIMVIGENCIA <> :OLD.DTFIMVIGENCIA
  THEN
    :NEW.DTESOCIAL := SYSDATE;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1005_EH
  AFTER INSERT OR UPDATE
  ON ESTRUTURAH FOR EACH ROW
BEGIN
  IF INSERTING OR
     (UPDATING AND (:NEW.CDCEIESTRUT <> :OLD.CDCEIESTRUT OR
                    :NEW.CDCNAE <> :OLD.CDCNAE OR
                    :NEW.VRFAP <> :OLD.VRFAP)
     )
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRESTRUTURAM = :NEW.NRESTRUTURAM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1005_CNAEFISC
  AFTER UPDATE
  ON CNAEFISCAL FOR EACH ROW
BEGIN
  IF :NEW.VRALIQRAT <> :OLD.VRALIQRAT
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRESTRUTURAM) IN (SELECT EM.NRORG, EM.NRESTRUTURAM
                                       FROM ESTRUTURAM EM
                                       JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                                                         AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                                                         AND EH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                                                   WHERE H1.NRORG = EH.NRORG
                                                                                     AND H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                                                     AND H1.DTMESCOMPETENC <= SYSDATE)
                                      WHERE EH.CDCNAE = :NEW.CDCNAE);
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1005_PTACESSO
  AFTER INSERT OR UPDATE OR DELETE
  ON GPE_PONTOACESSO FOR EACH ROW
BEGIN
  IF INSERTING OR
     (UPDATING AND :NEW.NRTPREGIPONTO <> :OLD.NRTPREGIPONTO)
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRESTRUTURAM = :NEW.NRESTRUTURAM;
  ELSIF DELETING THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRESTRUTURAM = :OLD.NRESTRUTURAM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1005_ENTEDUC
  AFTER INSERT OR UPDATE OR DELETE
  ON HIERARQUIAORG FOR EACH ROW
BEGIN
  IF (INSERTING AND :NEW.NRTIPOHIERARQORG = 71) OR
     (UPDATING AND :NEW.NRTIPOHIERARQORG = 71 AND :NEW.NRESTRUTURAMREL <> :OLD.NRESTRUTURAMREL)
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRESTRUTURAM = :NEW.NRESTRUTURAMSUP;
  ELSIF DELETING AND :OLD.NRTIPOHIERARQORG = 71 THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRESTRUTURAM = :OLD.NRESTRUTURAMSUP;
  END IF;
END;

-- ============================================================
--   EVENTO: S-1010
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S1010_EVENTO
  AFTER INSERT OR UPDATE
  ON FPA_EVENTOH FOR EACH ROW
BEGIN
  IF INSERTING OR 
    (UPDATING AND
        --VERIFICA SE HOUVE ALTERAÇÃO NOS CAMPOS QUE SÃO ENVIADOS NO EVENTO S-1010
        --CAMPOS: NREVENTOH, DSOBSERVACAO, IDEVENTODEMONST, NRORG, DTMESCOMPETENC, NRNATURUBR
        (:NEW.NREVENTOH       <> :OLD.NREVENTOH       OR 
         :NEW.DSOBSERVACAO    <> :OLD.DSOBSERVACAO    OR 
         (:NEW.DSOBSERVACAO IS NULL AND :OLD.DSOBSERVACAO IS NOT NULL) OR (:NEW.DSOBSERVACAO IS NOT NULL AND :OLD.DSOBSERVACAO IS NULL) OR
         :NEW.IDEVENTODEMONST <> :OLD.IDEVENTODEMONST OR 
         :NEW.NRORG           <> :OLD.NRORG           OR 
         :NEW.DTMESCOMPETENC  <> :OLD.DTMESCOMPETENC  OR 
         :NEW.NRNATURUBR      <> :OLD.NRNATURUBR      OR 
         (:NEW.NRNATURUBR IS NULL AND :OLD.NRNATURUBR IS NOT NULL) OR (:NEW.NRNATURUBR IS NOT NULL AND :OLD.NRNATURUBR IS NULL)))
  THEN
    UPDATE FPA_EVENTOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG     = :NEW.NRORG
       AND NREVENTOM = :NEW.NREVENTOM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_DTESOCIAL_INCIDEVENTO
  AFTER INSERT
  ON FPA_INCIDEVENTO FOR EACH ROW
BEGIN
  UPDATE FPA_EVENTOM
    SET DTESOCIAL = SYSDATE
  WHERE NRORG     = :NEW.NRORG
    AND NREVENTOM = :NEW.NREVENTOM;
END;

-- ============================================================
--   EVENTO: S-1060
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S1060_EM
  BEFORE UPDATE
  ON ESTRUTURAM FOR EACH ROW
BEGIN
  IF :NEW.DTINIVIGENCIA <> :OLD.DTINIVIGENCIA OR
     :NEW.DTFIMVIGENCIA <> :OLD.DTFIMVIGENCIA
  THEN
    :NEW.DTESOCIAL := SYSDATE;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1060_EH
  AFTER INSERT OR UPDATE
  ON ESTRUTURAH FOR EACH ROW
BEGIN
  IF INSERTING OR (UPDATING AND :NEW.NMESTRUTURAH <> :OLD.NMESTRUTURAH)
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRESTRUTURAM = :NEW.NRESTRUTURAM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1060_FATRISCO
  AFTER INSERT OR UPDATE OR DELETE
  ON SST_RELESTRUTRISCO FOR EACH ROW
BEGIN
  IF INSERTING OR (UPDATING AND :NEW.NRFATORRISCO <> :OLD.NRFATORRISCO)
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRESTRUTURAM = :NEW.NRESTRUTURAM;
  ELSIF DELETING
  THEN
    UPDATE ESTRUTURAM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRESTRUTURAM = :OLD.NRESTRUTURAM;
  END IF;
END;

-- ============================================================
--   EVENTO: S-1070
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S1070
  BEFORE UPDATE
  ON GPE_PROCESSADMJUD FOR EACH ROW
BEGIN
  IF :NEW.NRTPPROCESSADJU <> :OLD.NRTPPROCESSADJU OR
     :NEW.CDPROCESSADMJUD <> :OLD.CDPROCESSADMJUD OR
     :NEW.DTINIVIGENCIA <> :OLD.DTINIVIGENCIA OR
     :NEW.DTFIMVIGENCIA <> :OLD.DTFIMVIGENCIA OR
     :NEW.SGUFVARAPROADJU <> :OLD.SGUFVARAPROADJU OR
     :NEW.CDMUNIVARPRADJU <> :OLD.CDMUNIVARPRADJU OR
     :NEW.CDVARAPROCEADJU <> :OLD.CDVARAPROCEADJU
  THEN
    :NEW.DTESOCIAL := SYSDATE;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S1070_ITEM
  AFTER INSERT OR UPDATE OR DELETE
  ON GPE_ITEMPROCADMJUD FOR EACH ROW
BEGIN
  IF INSERTING OR
     (UPDATING AND (:NEW.NRSUSPEXIGITPROC <> :OLD.NRSUSPEXIGITPROC OR
                    :NEW.DTITEMPROCADMJUD <> :OLD.DTITEMPROCADMJUD OR
                    :NEW.IDDEPOMONTITPROC <> :OLD.IDDEPOMONTITPROC)
     )
  THEN
    UPDATE GPE_PROCESSADMJUD
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPROCESSADMJUD = :NEW.NRPROCESSADMJUD;
  ELSIF DELETING
  THEN
    UPDATE GPE_PROCESSADMJUD
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRPROCESSADMJUD = :OLD.NRPROCESSADMJUD;
  END IF;
END;

-- ============================================================
--   EVENTO: S-2205
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S2205_PH
  AFTER UPDATE
  ON GPE_PESSOAH FOR EACH ROW
BEGIN
  IF :NEW.NRCPFPESSOA <> :OLD.NRCPFPESSOA OR
     :NEW.NRPISPASEPPES <> :OLD.NRPISPASEPPES OR
     :NEW.NMPESSOA <> :OLD.NMPESSOA OR
     :NEW.IDSEXOPESSOA <> :OLD.IDSEXOPESSOA OR
     :NEW.DTNASCPESSOA <> :OLD.DTNASCPESSOA OR
     :NEW.CDPAIS <> :OLD.CDPAIS OR
     :NEW.SGESTADO <> :OLD.SGESTADO OR
     :NEW.CDMUNICIPIO <> :OLD.CDMUNICIPIO OR
     :NEW.NRCTPSPESSOA <> :OLD.NRCTPSPESSOA OR
     :NEW.NRSERIECTPSPES <> :OLD.NRSERIECTPSPES OR
     :NEW.SGUFCTPSPES <> :OLD.SGUFCTPSPES OR
     :NEW.NRRGPESSOA <> :OLD.NRRGPESSOA OR
     :NEW.CDEXRGPESSOA <> :OLD.CDEXRGPESSOA OR
     :NEW.DTEXRGPESSOA <> :OLD.DTEXRGPESSOA OR
     :NEW.NRDOCUESTRANG <> :OLD.NRDOCUESTRANG OR
     :NEW.DSEXPDOCESTR <> :OLD.DSEXPDOCESTR OR
     :NEW.SGUFHABCARPES <> :OLD.SGUFHABCARPES OR
     :NEW.NRCARTHABPES <> :OLD.NRCARTHABPES OR
     :NEW.DTHABCARTPES <> :OLD.DTHABCARTPES OR
     :NEW.DTVALHABCARTPES <> :OLD.DTVALHABCARTPES OR
     :NEW.DSCATEGHABCART <> :OLD.DSCATEGHABCART OR
     :NEW.DTCHEGADAPAIS <> :OLD.DTCHEGADAPAIS OR
     :NEW.IDPOSVISTOPERM <> :OLD.IDPOSVISTOPERM OR
     :NEW.NRANOCHEGAPAIS <> :OLD.NRANOCHEGAPAIS OR
     :NEW.NRCONDFISPES <> :OLD.NRCONDFISPES OR
     :NEW.NRCLASSESTRANG <> :OLD.NRCLASSESTRANG OR
     :NEW.NRRACAPESSOA <> :OLD.NRRACAPESSOA OR
     :NEW.CDESTACIVIL <> :OLD.CDESTACIVIL OR
     :NEW.NRGRAUINSTR <> :OLD.NRGRAUINSTR OR
     :NEW.NRNACIONALID <> :OLD.NRNACIONALID
  THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPESSOA = :NEW.NRPESSOA;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_RELACPARC
  AFTER INSERT OR DELETE
  ON RELACIONAPARC FOR EACH ROW
BEGIN
  IF INSERTING AND :NEW.NRTIPORELACIONA IN (1,2,3,4) THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPARCNEGOCIO = :NEW.NRPARCNEGOCIO;
  ELSIF DELETING AND :OLD.NRTIPORELACIONA IN (1,2,3,4) THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRPARCNEGOCIO = :OLD.NRPARCNEGOCIO;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_ENDERECO
  AFTER INSERT OR UPDATE OR DELETE
  ON ENDERECOPARC FOR EACH ROW
BEGIN
  IF INSERTING AND :NEW.CDTIPOENDERECO IN ('PRINCIPAL','EXTERIOR') THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPARCNEGOCIO = :NEW.NRPARCNEGOCIO;
  ELSIF UPDATING AND :NEW.CDTIPOENDERECO IN ('PRINCIPAL','EXTERIOR') AND
        (:NEW.CDPAIS <> :OLD.CDPAIS OR
         :NEW.SGESTADO <> :OLD.SGESTADO OR
         :NEW.CDMUNICIPIO <> :OLD.CDMUNICIPIO OR
         :NEW.CDLOGRADOURO <> :OLD.CDLOGRADOURO OR
         :NEW.DSENDERECO <> :OLD.DSENDERECO OR
         :NEW.NRIMOVELENDERECO <> :OLD.NRIMOVELENDERECO OR
         :NEW.DSCOMPLEENDERECO <> :OLD.DSCOMPLEENDERECO OR
         :NEW.NMBAIRROENDERECO <> :OLD.NMBAIRROENDERECO OR
         :NEW.NRCEPENDERECO <> :OLD.NRCEPENDERECO)
  THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPARCNEGOCIO = :NEW.NRPARCNEGOCIO;
  ELSIF DELETING AND :NEW.CDTIPOENDERECO IN ('PRINCIPAL','EXTERIOR') THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRPARCNEGOCIO = :OLD.NRPARCNEGOCIO;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_COMUNICA
  AFTER INSERT OR UPDATE OR DELETE
  ON COMUNICAPARC FOR EACH ROW
BEGIN
  IF INSERTING AND :NEW.CDFORMACOMU IN ('01','02','03','04','05','06') THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPARCNEGOCIO = :NEW.NRPARCNEGOCIO;
  ELSIF UPDATING AND :NEW.CDFORMACOMU IN ('01','02','03','04','05','06') AND
        (:NEW.CDPREFIXCOMUPARC <> :OLD.CDPREFIXCOMUPARC OR
         :NEW.CDCOMUNICAPARC <> :OLD.CDCOMUNICAPARC)
  THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRPARCNEGOCIO = :NEW.NRPARCNEGOCIO;
  ELSIF DELETING AND :NEW.CDFORMACOMU IN ('01','02','03','04','05','06') THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRPARCNEGOCIO = :OLD.NRPARCNEGOCIO;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_CLASSESTRA
  AFTER UPDATE
  ON GPE_CLASSESTRANG FOR EACH ROW
BEGIN
  IF :NEW.CDESOCIAL <> :OLD.CDESOCIAL THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.NRCLASSESTRANG = :NEW.NRCLASSESTRANG
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_RACAPESS
  AFTER UPDATE
  ON GPE_RACAPESSOA FOR EACH ROW
BEGIN
  IF :NEW.CDESOCIAL <> :OLD.CDESOCIAL THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.NRRACAPESSOA = :NEW.NRRACAPESSOA
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_ESTCIVIL
  AFTER UPDATE
  ON ESTADOCIVIL FOR EACH ROW
BEGIN
  IF :NEW.CDESOCIAL <> :OLD.CDESOCIAL THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.CDESTACIVIL = :NEW.CDESTACIVIL
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_GRAUINST
  AFTER UPDATE
  ON GPE_GRAUINSTR FOR EACH ROW
BEGIN
  IF :NEW.CDESOCIAL <> :OLD.CDESOCIAL THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.NRGRAUINSTR = :NEW.NRGRAUINSTR
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_NACIONALID
  AFTER UPDATE
  ON GPE_NACIONALIDADE FOR EACH ROW
BEGIN
  IF :NEW.CDPAIS <> :OLD.CDPAIS THEN
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.NRNACIONALID = :NEW.NRNACIONALIDADE
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_PAIS
  AFTER UPDATE
  ON PAIS FOR EACH ROW
BEGIN
  IF :NEW.CDESOCIAL <> :OLD.CDESOCIAL THEN
    /*PAIS DA PESSOA*/
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.CDPAIS = :NEW.CDPAIS
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
    
    /*PAIS DO ENDERECO DA PESSOA*/
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPARCNEGOCIO) IN (SELECT EP.NRORG, EP.NRPARCNEGOCIO
                                        FROM ENDERECOPARC EP
                                       WHERE EP.CDPAIS = :NEW.CDPAIS
                                         AND EP.CDTIPOENDERECO IN ('PRINCIPAL','EXTERIOR'));
    
    /*PAIS DA NACIONALIDADE DA PESSOA*/
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                   JOIN GPE_NACIONALIDADE NA ON NA.NRNACIONALIDADE = PH.NRNACIONALID
                                                            AND NA.CDPAIS = :NEW.CDPAIS
                                  WHERE PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2205_MUNICIPIO
  AFTER UPDATE
  ON MUNICIPIO FOR EACH ROW
BEGIN
  IF :NEW.CDMUNICIBGE <> :OLD.CDMUNICIBGE THEN
    /*MUNICIPIO DA PESSOA*/
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPESSOA) IN (SELECT PH.NRORG, PH.NRPESSOA
                                   FROM GPE_PESSOAH PH
                                  WHERE PH.CDMUNICIPIO = :NEW.CDMUNICIPIO
                                    AND PH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                                              WHERE H1.NRORG = PH.NRORG
                                                                AND H1.NRPESSOA = PH.NRPESSOA
                                                                AND H1.DTMESCOMPETENC <= SYSDATE));
    
    /*MUNICIPIO DO ENDERECO DA PESSOA*/
    UPDATE GPE_PESSOA
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRPARCNEGOCIO) IN (SELECT EP.NRORG, EP.NRPARCNEGOCIO
                                        FROM ENDERECOPARC EP
                                       WHERE EP.CDMUNICIPIO = :NEW.CDMUNICIPIO
                                         AND EP.CDTIPOENDERECO IN ('PRINCIPAL','EXTERIOR'));
  END IF;
END;

-- ============================================================
--   EVENTO: S-2206
-- ============================================================
CREATE OR REPLACE TRIGGER ESO_HIST_S2206_VM
  BEFORE UPDATE
  ON GPE_VINCULOM FOR EACH ROW
BEGIN
  IF :NEW.NRVINCULOEMPREG <> :OLD.NRVINCULOEMPREG
  THEN
    :NEW.DTESOCIAL := SYSDATE;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2206_VH
  AFTER UPDATE
  ON GPE_VINCULOH FOR EACH ROW
BEGIN
  IF :NEW.NRTPREGIMEPREV <> :OLD.NRTPREGIMEPREV OR
     :NEW.NRCARGO <> :OLD.NRCARGO OR
     :NEW.NRFUNCAO <> :OLD.NRFUNCAO OR
     :NEW.DTFIMCONTRDETERMIN <> :OLD.DTFIMCONTRDETERMIN OR
     :NEW.NRESTRUTSIND <> :OLD.NRESTRUTSIND
  THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRVINCULOM = :NEW.NRVINCULOM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2206_SALARIO
  AFTER INSERT OR UPDATE OR DELETE
  ON GPE_ALTESALARIO FOR EACH ROW
BEGIN
  IF INSERTING THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRVINCULOM = :NEW.NRVINCULOM;
  ELSIF UPDATING AND (:NEW.VRSALARIO <> :OLD.VRSALARIO OR
                      :NEW.IDTPSALARIO <> :OLD.IDTPSALARIO OR
                      :NEW.DSOBSERVACAO <> :OLD.DSOBSERVACAO)
  THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRVINCULOM = :NEW.NRVINCULOM;
  ELSIF DELETING THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRVINCULOM = :OLD.NRVINCULOM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2206_ALTEESCALA
  AFTER INSERT OR UPDATE OR DELETE
  ON GPE_ALTEESCALA FOR EACH ROW
BEGIN
  IF INSERTING THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRVINCULOM = :NEW.NRVINCULOM;
  ELSIF UPDATING AND (:NEW.NRESCALATRABM <> :OLD.NRESCALATRABM OR
                      :NEW.NRTURNO <> :OLD.NRTURNO)
  THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :NEW.NRORG
       AND NRVINCULOM = :NEW.NRVINCULOM;
  ELSIF DELETING THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE NRORG = :OLD.NRORG
       AND NRVINCULOM = :OLD.NRVINCULOM;
  END IF;
END;

CREATE OR REPLACE TRIGGER ESO_HIST_S2206_ESCALA
  AFTER UPDATE
  ON GPE_ESCALATRABH FOR EACH ROW
BEGIN
  IF :NEW.QTHRSEMESCTRABH <> :OLD.QTHRSEMESCTRABH OR
     :NEW.NRTPJORNADA <> :OLD.NRTPJORNADA
  THEN
    UPDATE GPE_VINCULOM
       SET DTESOCIAL = SYSDATE
     WHERE (NRORG, NRVINCULOM) IN (SELECT AE.NRORG, AE.NRVINCULOM
                                     FROM GPE_ALTEESCALA AE
                                    WHERE AE.NRORG = :NEW.NRORG
                                      AND AE.NRESCALATRABM = :NEW.NRESCALATRABM
                                      AND (AE.DTFIMESCALA IS NULL OR AE.DTFIMESCALA > SYSDATE)
                                      AND AE.DTINIESCALA = (SELECT MAX(DTINIESCALA) FROM GPE_ALTEESCALA
                                                             WHERE GPE_ALTEESCALA.DTINIESCALA <= SYSDATE
                                                               AND (GPE_ALTEESCALA.DTFIMESCALA IS NULL OR GPE_ALTEESCALA.DTFIMESCALA > SYSDATE)
                                                               AND GPE_ALTEESCALA.NRVINCULOM = AE.NRVINCULOM
                                                               AND GPE_ALTEESCALA.NRORG = AE.NRORG));
  END IF;
END;